@@ -4,18 +4,20 @@ import React from 'react';
 import PropTypes from 'prop-types';
 
 var STYLE = {
-  padding: "0 20px",
-  overflowY: "auto"
+  padding: '0 20px',
+  overflowY: 'auto'
 };
 
 export default function ContentContainer(_ref) {
   var children = _ref.children,
       width = _ref.width,
-      height = _ref.height;
+      height = _ref.height,
+      _ref$style = _ref.style,
+      style = _ref$style === undefined ? {} : _ref$style;
 
   return React.createElement(
     'div',
-    { style: _extends({ width: width, height: height }, STYLE), onWheel: function onWheel(event) {
+    { style: _extends({ width: width, height: height }, STYLE, style), onWheel: function onWheel(event) {
         return event.stopPropagation();
       } },
     children
@@ -24,5 +26,6 @@ export default function ContentContainer(_ref) {
 
 ContentContainer.propsType = {
   width: PropTypes.number.isRequired,
-  height: PropTypes.number.isRequired
+  height: PropTypes.number.isRequired,
+  style: PropTypes.object
 };
\ No newline at end of file
