@@ -20,6 +20,8 @@ export const UPDATE_ZOOM_SCALE = 'UPDATE_ZOOM_SCALE';
 export const TOGGLE_SNAP = 'TOGGLE_SNAP';
 export const CHANGE_CATALOG_PAGE = 'CHANGE_CATALOG_PAGE';
 export const GO_BACK_TO_CATALOG_PAGE = 'GO_BACK_TO_CATALOG_PAGE';
+export const THROW_ERROR = 'THROW_ERROR';
+export const THROW_WARNING = 'THROW_WARNING';
 
 // ACTIONS viewer2D
 export const SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -99,7 +101,9 @@ export const PROJECT_ACTIONS = {
   UPDATE_ZOOM_SCALE,
   TOGGLE_SNAP,
   CHANGE_CATALOG_PAGE,
-  GO_BACK_TO_CATALOG_PAGE
+  GO_BACK_TO_CATALOG_PAGE,
+  THROW_ERROR,
+  THROW_WARNING
 };
 
 export const VIEWER2D_ACTIONS = {
